@@ -185,6 +185,15 @@ class MonotonicDimension(BaseQuantitativeDimension):
     def coordinates(self, value):
         self._get_coordinates(value)
 
+    @property
+    def coords(self):
+        """Alias for the `coordinates` attribute."""
+        return self.coordinates
+
+    @coords.setter
+    def coords(self, value):
+        self.coordinates = value
+
     @property
     def absolute_coordinates(self):
         """Return the absolute coordinates along the dimensions."""
